@@ -1,8 +1,7 @@
-from pytest import raises
 import yaml
 
-from html_table import example_yaml_data, generate
-from html_table_data import parse_json
+from mash.html_table import example_yaml_data, generate
+from mash.html_table_data import parse_json
 
 expected_html = """
 <table>
